==> huaweicloudsdkgaussdbfornosql-3.1.109-py2.py3-none-any.whl: huaweicloudsdkgaussdbfornosql/v3/model/rename_high_risk_commands_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class RenameHighRiskCommandsRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'commands': 'list[CommandInfo]'
    }

    attribute_map = {
        'commands': 'commands'
    }

    def __init__(self, commands=None):
        """RenameHighRiskCommandsRequest

        The model defined in huaweicloud sdk

        :param commands: 高危命令与对应重命名命令。
        :type commands: list[:class:`huaweicloudsdkgaussdbfornosql.v3.CommandInfo`]
        """
        
        

        self._commands = None
        self.discriminator = None

        self.commands = commands

    @property
    def commands(self):
        """Gets the commands of this RenameHighRiskCommandsRequest.

        高危命令与对应重命名命令。

        :return: The commands of this RenameHighRiskCommandsRequest.
        :rtype: list[:class:`huaweicloudsdkgaussdbfornosql.v3.CommandInfo`]
        """
        return self._commands

    @commands.setter
    def commands(self, commands):
        """Sets the commands of this RenameHighRiskCommandsRequest.

        高危命令与对应重命名命令。

        :param commands: The commands of this RenameHighRiskCommandsRequest.
        :type commands: list[:class:`huaweicloudsdkgaussdbfornosql.v3.CommandInfo`]
        """
        self._commands = commands

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RenameHighRiskCommandsRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkgaussdbfornosql-3.1.149-py2.py3-none-any.whl: huaweicloudsdkgaussdbfornosql/v3/model/rename_high_risk_commands_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class RenameHighRiskCommandsRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'commands': 'list[CommandInfo]'
    }

    attribute_map = {
        'commands': 'commands'
    }

    def __init__(self, commands=None):
        r"""RenameHighRiskCommandsRequest

        The model defined in huaweicloud sdk

        :param commands: 高危命令与对应重命名命令。
        :type commands: list[:class:`huaweicloudsdkgaussdbfornosql.v3.CommandInfo`]
        """
        
        

        self._commands = None
        self.discriminator = None

        self.commands = commands

    @property
    def commands(self):
        r"""Gets the commands of this RenameHighRiskCommandsRequest.

        高危命令与对应重命名命令。

        :return: The commands of this RenameHighRiskCommandsRequest.
        :rtype: list[:class:`huaweicloudsdkgaussdbfornosql.v3.CommandInfo`]
        """
        return self._commands

    @commands.setter
    def commands(self, commands):
        r"""Sets the commands of this RenameHighRiskCommandsRequest.

        高危命令与对应重命名命令。

        :param commands: The commands of this RenameHighRiskCommandsRequest.
        :type commands: list[:class:`huaweicloudsdkgaussdbfornosql.v3.CommandInfo`]
        """
        self._commands = commands

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RenameHighRiskCommandsRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
